<?php
namespace Datec\DatecJobmarket\Controller;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use Datec\DatecJobmarket\Domain\Model\FacilityType;
use Datec\DatecJobmarket\Domain\Model\Jobentry;
use Datec\DatecJobmarket\Domain\Model\Jobgroup;
use Datec\DatecJobmarket\Domain\Model\Qualification;
use Datec\DatecJobmarket\Domain\Model\WorktimeType;
use Datec\DatecJobmarket\Domain\Repository\FacilityTypeRepository;
use Datec\DatecJobmarket\Domain\Repository\JobentryRepository;
use Datec\DatecJobmarket\Domain\Repository\JobgroupRepository;
use Datec\DatecJobmarket\Domain\Repository\QualificationRepository;
use Datec\DatecJobmarket\Domain\Repository\WorktimeTypeRepository;
use Datec\DatecJobmarket\Services\MailService;
use TYPO3\CMS\Core\Messaging\FlashMessage;
use TYPO3\CMS\Extbase\Mvc\Controller\ActionController;
use TYPO3\CMS\Extbase\Mvc\Exception\StopActionException;
use TYPO3\CMS\Extbase\Mvc\Exception\UnsupportedRequestTypeException;
use TYPO3\CMS\Extbase\Persistence\Exception\IllegalObjectTypeException;
use TYPO3\CMS\Extbase\Persistence\Exception\UnknownObjectException;
use TYPO3\CMS\Extbase\Persistence\PersistenceManagerInterface;
use TYPO3\CMS\Extbase\Property\TypeConverter\DateTimeConverter;
use TYPO3\CMS\Extbase\Property\TypeConverter\PersistentObjectConverter;
use TYPO3\CMS\Extbase\Utility\LocalizationUtility;

/**
 * @package datec_jobmarket
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 */
class JobentryController extends ActionController {

	/**
     * extKey
     *
	 * @var string $extKey
	 */
	protected $extKey;

	/**
     * arguments,
	 * taken from $this->request->getArguments()
	 *
	 * @var array
	 */
	protected $args = [];

    /**
     * jobentry
     *
     * @var Jobentry
     */
    protected $jobentry;

    /**
     * jobgroups
     *
     * @var array
     */
    protected $jobgroups;

    /**
     * qualifications
     *
     * @var array
     */
    protected $qualifications;

    /**
     * neUser
     *
     * @var array
     */
    protected $beUser;

    /**
     * jobentryRepository
     *
     * @var JobentryRepository
     * */
    protected $jobentryRepository;

    /**
     * jobgroupRepository
     *
     * @var JobgroupRepository
     */
    protected $jobgroupRepository;

    /**
     * qualificationRepository
     *
     * @var QualificationRepository
     * */
    protected $qualificationRepository;

    /**
     * facilityTypeRepository
     *
     * @var FacilityTypeRepository
     * */
    protected $facilityTypeRepository;

    /**
     * orktimeTypeRepository
     *
     * @var WorktimeTypeRepository
     * */
    protected $worktimeTypeRepository;

    /**
     * $mailService
     * @var MailService
     * */
    protected $mailService;

    /**
     * persistence manager
     *
     * @var PersistenceManagerInterface
     * */
    protected $persistenceManager;


    /**
     * @param FacilityTypeRepository $facilityTypeRepository
     */
    public function injectFacilityTypeRepository(FacilityTypeRepository $facilityTypeRepository)
    {
        $this->facilityTypeRepository = $facilityTypeRepository;
    }

    /**
     * @param JobentryRepository $jobentryRepository
     */
    public function injectJobentryRepository(JobentryRepository $jobentryRepository)
    {
        $this->jobentryRepository = $jobentryRepository;
    }

    /**
     * @param JobgroupRepository $jobgroupRepository
     */
    public function injectJobgroupRepository(JobgroupRepository $jobgroupRepository)
    {
        $this->jobgroupRepository = $jobgroupRepository;
    }

    /**
     * @param MailService $mailService
     */
    public function injectMailService(MailService $mailService)
    {
        $this->mailService = $mailService;
    }

    /**
     * @param PersistenceManagerInterface $persistenceManager
     */
    public function injectPersistenceManager(PersistenceManagerInterface $persistenceManager)
    {
        $this->persistenceManager = $persistenceManager;
    }

    /**
     * @param QualificationRepository $qualificationRepository
     */
    public function injectQualificationRepository(QualificationRepository $qualificationRepository)
    {
        $this->qualificationRepository = $qualificationRepository;
    }

    /**
     * @param WorktimeTypeRepository $worktimeTypeRepository
     */
    public function injectWorktimeTypeRepository(WorktimeTypeRepository $worktimeTypeRepository)
    {
        $this->worktimeTypeRepository = $worktimeTypeRepository;
    }
	
	/**
	 * initialize current action
	 * @return void
	 */
	public function initializeAction() {
		$this->extKey = $this->request->getControllerExtensionKey();
		$this->args = $this->request->getArguments();
		$this->beUser = $this->getBEuser();
	}
	
	/**
	 * initialize create action
	 * 
	 * @return void
	 */
	protected function initializeCreateAction() {		
		// allow all Properties to be mapped and dates to have the current format
		if (isset($this->arguments['jobentry'])) {
			$this->arguments['jobentry']
				->getPropertyMappingConfiguration()
				->allowAllProperties()
				->setTypeConverterOption(
					PersistentObjectConverter::class,
					PersistentObjectConverter::CONFIGURATION_CREATION_ALLOWED,
					TRUE
				);
			$this->arguments['jobentry']
			    ->getPropertyMappingConfiguration()
				->forProperty('beginfrom')
				->setTypeConverterOption(
                    DateTimeConverter::class,
                    DateTimeConverter::CONFIGURATION_DATE_FORMAT,
                    $this->settings['display']['dateFormat']
				);
			$this->arguments['jobentry']
			    ->getPropertyMappingConfiguration()
				->forProperty('limitedto')
				->setTypeConverterOption(
                    DateTimeConverter::class,
                    DateTimeConverter::CONFIGURATION_DATE_FORMAT,
                    $this->settings['display']['dateFormat']
				);
		}
	}
	
	/**
	 * initialize new action
	 * 
	 * @return void
	 */
	protected function initializeNewAction() {		
		// allow all Properties to be mapped and dates to have the current format
		if (isset($this->arguments['jobentry'])) {
			$this->arguments['jobentry']
				->getPropertyMappingConfiguration()
				->allowAllProperties()
				->setTypeConverterOption(
					PersistentObjectConverter::class,
					PersistentObjectConverter::CONFIGURATION_CREATION_ALLOWED,
					TRUE
				);
			$this->arguments['jobentry']
			    ->getPropertyMappingConfiguration()
				->forProperty('beginfrom')
				->setTypeConverterOption(
                    DateTimeConverter::class,
                    DateTimeConverter::CONFIGURATION_DATE_FORMAT,
                    $this->settings['display']['dateFormat']
				);
			$this->arguments['jobentry']
			    ->getPropertyMappingConfiguration()
				->forProperty('limitedto')
				->setTypeConverterOption(
                    DateTimeConverter::class,
                    DateTimeConverter::CONFIGURATION_DATE_FORMAT,
                    $this->settings['display']['dateFormat']
				);
		}
	}
	
	/**
	 * initialize update action
	 *
	 * @return void
	 */
	protected function initializeUpdateAction() {
		// allow all Properties to be mapped and dates to have the current format
		if (isset($this->arguments['jobentry'])) {
			$this->arguments['jobentry']
				->getPropertyMappingConfiguration()
				->allowAllProperties()
				->setTypeConverterOption(
					PersistentObjectConverter::class,
					PersistentObjectConverter::CONFIGURATION_CREATION_ALLOWED,
					TRUE
				);
			$this->arguments['jobentry']
			    ->getPropertyMappingConfiguration()
				->forProperty('beginfrom')
				->setTypeConverterOption(
                    DateTimeConverter::class,
                    DateTimeConverter::CONFIGURATION_DATE_FORMAT,
                    $this->settings['display']['dateFormat']
				);
			$this->arguments['jobentry']
                ->getPropertyMappingConfiguration()
				->forProperty('limitedto')
				->setTypeConverterOption(
				    DateTimeConverter::class,
                    DateTimeConverter::CONFIGURATION_DATE_FORMAT,
                    $this->settings['display']['dateFormat']
				);
		}
	}
	
	/**
	 * initialize delete action
	 *
	 * @return void
	 */
	protected function initializeDeleteAction() {
		// allow all Properties to be mapped and dates to have the current format
		if (isset($this->arguments['jobentry'])) {
			$this->arguments['jobentry']
                ->getPropertyMappingConfiguration()
                ->allowAllProperties()
                ->setTypeConverterOption(
                    PersistentObjectConverter::class,
                    PersistentObjectConverter::CONFIGURATION_CREATION_ALLOWED,
                    TRUE
			    );
			$this->arguments['jobentry']
                ->getPropertyMappingConfiguration()
                ->forProperty('beginfrom')
                ->setTypeConverterOption(
                    DateTimeConverter::class,
                    DateTimeConverter::CONFIGURATION_DATE_FORMAT,
                    $this->settings['display']['dateFormat']
                );
			$this->arguments['jobentry']
                ->getPropertyMappingConfiguration()
                ->forProperty('limitedto')
                ->setTypeConverterOption(
                    DateTimeConverter::class,
                    DateTimeConverter::CONFIGURATION_DATE_FORMAT,
                    $this->settings['display']['dateFormat']
                );
		}
	}

    /**
     * action searchForm
     *
     * @return void
     * @throws StopActionException
     */
	public function searchFormAction() {
		$this->setJobgroupOptions(TRUE, TRUE);
		
		if ($GLOBALS['TSFE']->id == $this->settings['showExportPid']) {
			$this->forward('showExport', 'Jobentry', 'DatecJobmarket');
		}
		
		$this->view->assign('jobgroups', $this->jobgroups);
		$this->view->assign('searchArguments', $this->args);
	}

    /**
     * action search
     *
     * @return void
     * @throws StopActionException
     * @throws UnsupportedRequestTypeException
     */
	public function searchAction() {
		if($this->request->hasArgument('newAction')) {
            unset($this->args['jobgroups']);
			$this->redirect('new', 'Jobentry', 'datecjobmarket', $this->args);
		}
		$this->setJobgroupOptions(TRUE);						
		$searchParams = [];
		$searchParams['jobtype'] = $this->args['jobtype'];		
		$searchParams['jobgroups'] = $this->args['jobgroups'];		
		$searchParams['zipcode'] = $this->args['zipSearchArea'];
		$searchParams['workarea'] = $this->args['zipSearchArea'];
		if($this->beUser) {
			$searchParams['hidden'] = 1;
		}
		
		$jobentries = $this->jobentryRepository->searchJobentries($searchParams);
		if ($jobentries === FALSE) {
			$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.searchError',$this->extKey), '', FlashMessage::ERROR);
			$this->redirect('searchForm', 'Jobentry', 'datecjobmarket', $this->args);
		} 
		else if (count($jobentries) < 1 || count($jobentries) === FALSE) {
			$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.searchNone',$this->extKey), '', FlashMessage::WARNING);
			$this->redirect('searchForm', 'Jobentry', 'datecjobmarket', $this->args);
		}
		else {
			$this->view->assign('jobentries', $jobentries);
		}		
		
		$this->view->assign('beUser', $this->beUser);
		$this->view->assign('jobgroups', $this->jobgroups);
		$this->view->assign('searchArguments', $this->args);
	}

	/**
	 * action new
	 *
	 * @param Jobentry $jobentry
	 * @dontvalidate $jobentry
	 * @return void
	 */
	public function newAction(Jobentry $jobentry = NULL) {
		$this->setJobgroupOptions();
		$this->setQualificationOptions();
		
		$facilityTypesResult = $this->facilityTypeRepository->findAll();
		if ($facilityTypesResult) {
			$this->view->assign("facilityTypes", $facilityTypesResult);
		}
		
		$worktimeTypesResult = $this->worktimeTypeRepository->findAll();
		if ($worktimeTypesResult) {
			$this->view->assign("worktimeTypes", $worktimeTypesResult);
		}

		$this->view->assign('jobgroups', $this->jobgroups);
		$this->view->assign('qualifications', $this->qualifications);
		$this->view->assign('jobentry', $jobentry);
		$this->view->assign('settings', $this->settings);
		$this->view->assign('lang', $GLOBALS['TSFE']->lang);
	}

    /**
     * action create
     *
     * @param Jobentry $jobentry
     * @return void
     * @throws StopActionException
     * @throws UnsupportedRequestTypeException
     * @throws IllegalObjectTypeException
     */
	public function createAction(Jobentry $jobentry) {
		if($this->request->hasArgument('back_button')) {
			$this->redirect('searchForm', 'Jobentry', 'datecjobmarket', $this->args);
		} 
		
		if (isset($_POST['mail']) && $_POST['mail'] != '') { // spam protection field, honeypot should be empty
			$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.spam',$this->extKey), '', FlashMessage::WARNING);
		} else {		
			$workarea = str_replace(' ','',$jobentry->getWorkarea()); // remove spaces for DB
			$jobentry->setWorkarea($workarea);		
			
			$startDateTime = new \DateTime();
			$endDateTime = clone $startDateTime;
			$endDateTime->modify('+'.$this->settings['jobentry']['defaultValidToDays'].' day');
			$jobentry->setStarttime($startDateTime);
			$jobentry->setEndtime($endDateTime);
			
			if ($this->settings['jobentry']['defaultFacilityType'] != 0) {
			    /* @var FacilityType $facilityTypeResult */
				$facilityTypeResult = $this->facilityTypeRepository->findByUid($this->settings['jobentry']['defaultFacilityType']);
				if ($facilityTypeResult) {
					$jobentry->setFacilityType($facilityTypeResult);
				}
			}
			
			if ($this->settings['jobentry']['defaultWorktimeType'] != 0) {
                /* @var WorktimeType $worktimeTypeResult */
				$worktimeTypeResult = $this->worktimeTypeRepository->findByUid($this->settings['jobentry']['defaultWorktimeType']);
				if ($worktimeTypeResult) {
					$jobentry->setWorktimeType($worktimeTypeResult);
				}
			}
				
			$this->jobentryRepository->add($jobentry);
			$this->persistenceManager->persistAll();
			$msg = $this->mailService->generateInfoMail($jobentry, $this->extKey, $this->request->getControllerExtensionName());
			$this->mailService->sendInfoMail($msg, $this->settings, $this->extKey);
			
			$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.created',$this->extKey), '', FlashMessage::OK);
		}
		$this->redirect('searchForm', 'Jobentry', 'datecjobmarket');
		$this->view->assign('lang', $GLOBALS['TSFE']->lang);
	}

    /**
     * action hide
     *
     * @param int $jobentryId
     * @return void
     * @throws IllegalObjectTypeException
     * @throws StopActionException
     * @throws UnknownObjectException
     * @throws UnsupportedRequestTypeException
     */
	public function hideAction(int $jobentryId) {
		if ($this->beUser) {
			$this->jobentry = $this->jobentryRepository->findByUid($jobentryId);
			if ($this->jobentry) {
				$hidden = ($this->jobentry->getHidden() == 1) ? 0 : 1;
				$this->jobentry->setHidden($hidden);
				
				$updateResult = $this->jobentryRepository->update($this->jobentry);		
				if ($updateResult === FALSE) {
					$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.hiddenError',$this->extKey, '', FlashMessage::OK).': '.$this->jobentry->getUid().' - "'.$this->jobentry->getTitle().'"', '', FlashMessage::WARNING);
				} else {
					$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.hidden',$this->extKey).': '.$this->jobentry->getUid().' - "'.$this->jobentry->getTitle().'"', '', FlashMessage::OK);
				}
			} else {
				$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.noJobentry',$this->extKey), '', FlashMessage::ERROR);
			}
		}	
		$this->redirect($this->args['searchArguments']['action'], $this->args['searchArguments']['controller'], 'datecjobmarket', $this->args['searchArguments']);
	}

    /**
     * action show
     *
     * @param int $jobentryId
     * @return void
     * @throws StopActionException
     * @throws UnsupportedRequestTypeException
     */
	public function showAction(int $jobentryId) {
		if($this->request->hasArgument('back_button')) {
			$this->redirect($this->args['searchArguments']['action'], $this->args['searchArguments']['controller'], 'datecjobmarket', $this->args['searchArguments']);
		}
		
		if($this->request->hasArgument("contact")) {
			$this->redirect('contactform', 'Jobentry', 'datecjobmarket', ['jobentryId' => $jobentryId]);
		}
		
		if($this->beUser) {
			$this->jobentry = $this->jobentryRepository->findByUid($jobentryId);
		} else {
			$this->jobentry = $this->jobentryRepository->findByUid($jobentryId, false, ['hidden']);
		}
		
		if($this->jobentry) {
			if($this->request->hasArgument('login_edit')) {
				if (!empty($this->args['ShowForm']['password'])) {
					if ($this->args['ShowForm']['password'] == $this->jobentry->getPassword()) {
						unset($this->args['ShowForm']['password']);
						$this->args['authHash'] = md5($this->jobentry->getPassword());
						
						if ($this->settings['security']['userEmailCompare']) { // compares email to secure ownership of the jobentry, requires frontend login with same email address
							if ($GLOBALS['TSFE']->user['email'] == $this->jobentry->getEmail()) {
								$this->redirect('edit', 'Jobentry', 'datecjobmarket', $this->args);
							} else {
								$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.emailWrong',$this->extKey), '', FlashMessage::WARNING);
							}
						} else {
							$this->redirect('edit', 'Jobentry', 'datecjobmarket', $this->args);
						}
					} else {
						$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.passwordWrong',$this->extKey), '', FlashMessage::WARNING);
					}
				} else {
					$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.passwordMissing',$this->extKey), '', FlashMessage::ERROR);
				}			
			}
		} else {
			$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.noJobentry',$this->extKey), '', FlashMessage::ERROR);
		}
		
		if($this->request->hasArgument('edit') && $this->beUser) {
			$this->redirect('edit', 'Jobentry', 'datecjobmarket', $this->args);
		}
		
		if($this->request->hasArgument('edit') && isset($this->args['authHash'])) {
			if ($this->args['authHash'] == md5($this->jobentry->getPassword())) {
				$this->redirect('edit', 'Jobentry', 'datecjobmarket', $this->args);
			} else {
				$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.hashWrong',$this->extKey), '', FlashMessage::WARNING);
			}
		}
		
		$this->view->assign('beUser', $this->beUser);
		$this->view->assign('jobentry', $this->jobentry);
		$this->view->assign('searchArguments', $this->args['searchArguments']);
	}
	
	/**
	 * action edit
	 *
     * @param int $jobentryId
	 * @return void
	 */
	public function editAction(int $jobentryId) {
		if($this->beUser) {
			$this->jobentry = $this->jobentryRepository->findByUid($jobentryId, true, ['hidden']);
		} else {
			$this->jobentry = $this->jobentryRepository->findByUid($jobentryId);
		}
		
		if($this->jobentry && $this->args['authHash'] || $this->beUser) {
			if ($this->args['authHash'] == md5($this->jobentry->getPassword()) || $this->beUser) {
				$this->setJobgroupOptions();
				$this->setQualificationOptions();
				
				$facilityTypesResult = $this->facilityTypeRepository->findAll();
				if ($facilityTypesResult) {
					$this->view->assign("facilityTypes", $facilityTypesResult);
				}
				
				$worktimeTypesResult = $this->worktimeTypeRepository->findAll();
				if ($worktimeTypesResult) {
					$this->view->assign("worktimeTypes", $worktimeTypesResult);
				}
				
				$this->view->assign('authHash', md5($this->jobentry->getPassword()));
			} else {
				$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.hashWrong',$this->extKey), '', FlashMessage::WARNING);
			}
		}

		$this->view->assign('jobgroups', $this->jobgroups);
		$this->view->assign('qualifications', $this->qualifications);
		$this->view->assign('jobentry', $this->jobentry);
		$this->view->assign('searchArguments', $this->args['searchArguments']);
		$this->view->assign('settings', $this->settings);
		$this->view->assign('lang', $GLOBALS['TSFE']->lang);
	}

    /**
     * action update
     *
     * @param Jobentry $jobentry
     * @return void
     * @throws IllegalObjectTypeException
     * @throws StopActionException
     * @throws UnknownObjectException
     * @throws UnsupportedRequestTypeException
     * @dontvalidate $jobentry
     */
	public function updateAction(Jobentry $jobentry) {
		if($this->request->hasArgument('back_button')) {
			$this->redirect($this->args['searchArguments']['action'], $this->args['searchArguments']['controller'], 'datecjobmarket', $this->args['searchArguments']);
		}
		
		if($this->request->hasArgument('deleteAction') && isset($this->args['authHash'])) {
			if ($this->args['authHash'] == md5($jobentry->getPassword())) {
				$this->redirect('delete', 'Jobentry', 'datecjobmarket', $this->args);
			} else {
				$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.hashWrong',$this->extKey), '', FlashMessage::WARNING);
			}	
		}
		
		if($this->request->hasArgument('updateAction') && isset($this->args['authHash'])) {			
			if ($this->settings['jobentry']['resetStarttimeAndEndtimeOnUpdate']) {
				$startDateTime = new \DateTime();
				$startDateTime->modify('-1 minute'); // prevents object from being not found right NOW
				$endDateTime = clone $startDateTime;
				$endDateTime->modify('+'.$this->settings['jobentry']['defaultValidToDays'].' day');
				$jobentry->setStarttime($startDateTime);
				$jobentry->setEndtime($endDateTime);
			}
			$this->jobentryRepository->update($jobentry);
			
			$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.updated',$this->extKey), '', FlashMessage::OK);
		}	
		$this->args['jobentry'] = $jobentry;
		$this->redirect('edit', 'Jobentry', 'datecjobmarket', $this->args);
	}

    /**
     * action delete
     *
     * @param int $jobentryId
     * @return void
     * @throws IllegalObjectTypeException
     * @throws StopActionException
     * @throws UnsupportedRequestTypeException
     */
	public function deleteAction(int $jobentryId) {
		$this->jobentry = $this->jobentryRepository->findByUid($jobentryId);
		if ($this->jobentry) {
			if(isset($this->args['authHash'])) {
				if ($this->args['authHash'] == md5($this->jobentry->getPassword())) {
					
					$this->jobentryRepository->remove($this->jobentry);
					$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.removed',$this->extKey), '', FlashMessage::OK);
				} else {
					$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.hashWrong',$this->extKey), '', FlashMessage::WARNING);
				}	
			}	
		} else {
			$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.noJobentry',$this->extKey), '', FlashMessage::ERROR);
		}
		
		$this->redirect($this->args['searchArguments']['action'], $this->args['searchArguments']['controller'], 'datecjobmarket', $this->args['searchArguments']);
	}
	
	/**
	 * action showExport
	 *
	 * @return void
	 */
	public function showExportAction() {
		// load split, because this is more performant in the output
		if($this->beUser) {
			$jobentryRequests = $this->jobentryRepository->findExportable(1);
			$jobentryOffers = $this->jobentryRepository->findExportable(2);
			if ($jobentryRequests) {
				$this->view->assign('jobentryRequests', $jobentryRequests);			
			} else {
				$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.searchError',$this->extKey), '', FlashMessage::ERROR);
			}			
			if ($jobentryOffers) {			
				$this->view->assign('jobentryOffers', $jobentryOffers);
			} else {
				$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.searchError',$this->extKey), '', FlashMessage::ERROR);
			}			
		} else {
			$this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.noBeUser',$this->extKey), '', FlashMessage::ERROR);
		}			
	}
	
	/**
	 * action newContactMessage
	 * @return void
	 */
	public function newContactMessageAction() {
		$this->view->assign("lang", $GLOBALS['TSFE']->lang);
		$this->view->assign("settings", $this->settings);
		$this->view->assign("jobentryId", $this->args['jobentryId']);
	}

    /**
     * action sendContactMessage
     * TODO: rework to use ContactMessage object
     *
     * @return void
     * @throws StopActionException
     * @throws UnsupportedRequestTypeException
     */
	public function sendContactMessageAction() {
        if (isset($_POST['mail']) && $_POST['mail'] != '') { // spam protection field, honeypot should be empty
            $this->addFlashMessage(LocalizationUtility::translate('tx_datecjobmarket.messages.spam',$this->extKey), '', FlashMessage::WARNING);
        } else {
            /* @var Jobentry $jobentry */
            $jobentry = $this->jobentryRepository->findByUid($this->request->getArgument("jobentryId"));
            $mailAdress = $this->request->getArgument("email");
            $contactMsg = $this->request->getArgument("message");

            $subject = LocalizationUtility::translate("tx_datecjobmarket.mail.subjects.contactMail", $this->extKey, [$jobentry->getTitle()]);
            $msg = $this->mailService->generateContactMail($mailAdress, $contactMsg, $this->request->getControllerExtensionName());

            if ($this->mailService->sendContactMail($msg, $jobentry, $subject, $this->settings)) {
                $this->addFlashMessage(LocalizationUtility::translate("tx_datecjobmarket.messages.contact.sendComplete", $this->extKey), "", FlashMessage::OK);
            } else {
                $this->addFlashMessage(LocalizationUtility::translate("tx_datecjobmarket.messages.contact.sendError", $this->extKey), "", FlashMessage::ERROR);
            }

            $this->redirect('newContactMessage', 'Jobentry', 'datecjobmarket', $this->args);
        }
	}
	
	/**
	 * set jobgroup options
	 * 
	 * @param boolean $prependAllOption puts an 'all' option before the rest
	 * @param boolean $checkAll all options should be checked if not in request arguments
	 * @return void
	 */
	private function setJobgroupOptions($prependAllOption = FALSE, $checkAll = FALSE) {	
		$jobgroupsResult = $this->jobgroupRepository->findAll();
		if (isset($this->jobentry)) {
			$jobentryJobgroups = $this->jobentry->getJobgroups();
		}
		
		if ($jobgroupsResult) {	
			$jobgroupsResult = $jobgroupsResult->toArray();			
			if (count($jobgroupsResult)) {
                if ($prependAllOption) {
                    $this->jobgroups[] = [
                        'value' => 0,
                        'label' => LocalizationUtility::translate('tx_datecjobmarket.labels.jobgroup_all',$this->extKey),
                        'checked' => isset($this->args['jobgroupsAll']) ? (($this->args['jobgroupsAll'] === "") ? FALSE : TRUE) : $checkAll,
                    ];
                }
                /* @var Jobgroup $jobgroup */
				foreach ($jobgroupsResult as $jobgroup) {
                    $this->jobgroups[] = [
                        'value' => $jobgroup->getUid(),
                        'label' => $jobgroup->getName(),
                        'checked' => (isset($this->args['jobgroups']) && !empty($this->args['jobgroups'])) ? in_array($jobgroup->getUid(), $this->args['jobgroups']) : (isset($jobentryJobgroups) ? $jobentryJobgroups->contains($jobgroup) : $checkAll),
					];
				}
			}
		}
	}
	
	/**
	 * set qualification options
	 *
	 * @param boolean $checkAll all options should be checked if not in request arguments
	 * @return void
	 */
	private function setQualificationOptions($checkAll = FALSE) {
		$qualificationsResult = $this->qualificationRepository->findAll();
		if (isset($this->jobentry)) {
			$jobentryQualifications = $this->jobentry->getQualifications();
		}
		
		if ($qualificationsResult) {
			$qualificationsResult = $qualificationsResult->toArray();				
			if (count($qualificationsResult)) {
                /* @var Qualification $qualification */
				foreach ($qualificationsResult as $qualification) {
                    $this->qualifications[] = [
						'value' => $qualification->getUid(), 
						'label' => $qualification->getName(), 
						'checked' => isset($this->args['qualifications']) ? in_array($qualification->getUid(), $this->args['qualifications']) : (isset($jobentryQualifications) ? $jobentryQualifications->contains($qualification) : $checkAll),
					];
				}
			}
		}
	}
	
	/**
	 * check for be user and retrieve his data
	 * this is needed to determine FE-editing
	 *
	 * @return array $beUser or boolean FALSE if no allowed user found
	 */
	private function getBEuser() {
		if(isset($GLOBALS['BE_USER']->user)) {
			$beUser = $GLOBALS['BE_USER']->user;
			$usersGroups = explode(',',$beUser['usergroup']);
			$allowedGroups = explode(',',$this->settings['allowedBEgroups4FEediting']); // these usergroups are configured to edit in FE
			foreach ($allowedGroups as $allowedGroup) {
				if($beUser['admin'] == 1 || in_array($allowedGroup, $usersGroups)) {
					return $beUser;
				}
			}			
		}

		return null;
	}

}