<?php
namespace Datec\DatecJobmarket\Task;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use Datec\DatecJobmarket\Domain\Repository\JobentryRepository;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Extbase\Object\ObjectManager;
use TYPO3\CMS\Scheduler\Task\AbstractTask;

/**
 * Task to delete job entries by set date parameters completly, thus cleanup the database.
 * @package datec_jobmarket
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 */
class CleanupTask extends AbstractTask {

	/**
	 * jobentryRepository
	 *
	 * @var JobentryRepository
	 */
	protected $jobentryRepository;
	
	/**
	 * @var int
	 */
	public $numberOfDays;
	
	/**
	 * injection of jobentryRepository
	 */
	private function injectJobentryRepository() {
		$objectManager = GeneralUtility::makeInstance(ObjectManager::class);
		$this->jobentryRepository = $objectManager->get(JobentryRepository::class);
	}
	
	/**
	 * @return boolean Success state of execution
	 */
	public function execute() {
		$this->injectJobentryRepository();
	
		$deleteDate = new \DateTime();
		$deleteDate->setTime(23, 59, 59);
		$deleteDate->modify('- '.$this->numberOfDays.' days');
	
		$jobentryDelete = $this->jobentryRepository->cleanupByDate($deleteDate->getTimestamp());
		if (!$jobentryDelete) { // db error
			return FALSE;
		}
	
		return TRUE;
	}
	
}