<?php
namespace Datec\DatecJobmarket\Task;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Core\Messaging\FlashMessage;
use TYPO3\CMS\Scheduler\AdditionalFieldProviderInterface;
use TYPO3\CMS\Scheduler\Controller\SchedulerModuleController;
use TYPO3\CMS\Scheduler\Task\AbstractTask;

/**
 * @package datec_jobmarket
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 */
class CleanupTaskAdditionalFieldProvider implements AdditionalFieldProviderInterface {
	
	/**
	 * Default period in days after wich to cleanup
	 *
	 * @var integer Default number of days
	 */
	protected $numberOfDays = 30;

    /**
     * @param array $taskInfo
     * @param CleanupTask $task
     * @param SchedulerModuleController $parentObject
     * @return array|mixed
     */
    public function getAdditionalFields(array &$taskInfo, $task, SchedulerModuleController $parentObject) {
		// Initialize selected fields
		if (empty($taskInfo['jobentry_cleanup_numberOfDays'])) {
			$taskInfo['jobentry_cleanup_numberOfDays'] = $this->numberOfDays;
			if ($parentObject->CMD === 'edit') {
				$taskInfo['jobentry_cleanup_numberOfDays'] = $task->numberOfDays;
			}
		}
	
		$fieldName = 'tx_scheduler[jobentry_cleanup_numberOfDays]';
		$fieldId = 'task_cleanup_numberOfDays';
		$fieldValue = (int)$taskInfo['jobentry_cleanup_numberOfDays'];
		$fieldHtml = '<input type="text" name="' . $fieldName . '" id="' . $fieldId . '" value="' . htmlspecialchars($fieldValue) . '" />';
	
		$additionalFields[$fieldId] = array(
				'code' => $fieldHtml,
				'label' => 'LLL:EXT:datec_jobmarket/Resources/Private/Language/locallang.xlf:tx_datecjobmarket.tasks.fields.numberOfDays',
				'cshKey' => '',
				'cshLabel' => $fieldId
		);
	
		return $additionalFields;
	}

    /**
     * @param array $submittedData
     * @param SchedulerModuleController $parentObject
     * @return bool
     */
    public function validateAdditionalFields(array &$submittedData, SchedulerModuleController $parentObject) {
		$result = TRUE;
		// Check if number of days is indeed a number and greater or equals to 0
		// If not, fail validation and issue error message
		if (!is_numeric($submittedData['jobentry_cleanup_numberOfDays'])) {
			$result = FALSE;
			$parentObject->addMessage(FlashMessage::ERROR, $GLOBALS['LANG']->sL('LLL:EXT:datec_jobmarket/Resources/Private/Language/locallang.xlf:tx_datecjobmarket.tasks.fields.numberOfDays.invalid'));
		}
		return $result;
	}

    /**
     * @param array $submittedData
     * @param CleanupTask $task
     */
    public function saveAdditionalFields(array $submittedData, AbstractTask $task) {
		$task->numberOfDays = (int)$submittedData['jobentry_cleanup_numberOfDays'];
	}
}