<?php
namespace Datec\DatecJobmarket\ViewHelpers\Format;

/**
 * View helper for email strings, replaces given signs for security 
 * (no link protection! - use f:link.email for that!)
 * 
 * ==== Examples ====
 * 
 * <code title="email string protection">
 *  <dv:format.strReplace replacements="{0:{0:'@',1:'(at)'}, 1:{0:'.',1:'(dot)'}}">{email}</dv:format.strReplace>
 *  // note that the array of replacements contains an arrays, put a search and replacement value in each
 * </code>
 * <output>
 * 	email(at)somewhere(dot)com
 * </output>
 * 
 * @author Philipp Roensch
 */
class StrReplaceViewHelper extends \TYPO3\CMS\Fluid\Core\ViewHelper\AbstractViewHelper {
	
	/**
	 * Replaces all strings given in array on contentm
	 * basically a wrapper for multiple PHP str_replace() calls
	 * 
	 * @param array $replacements list of replacements arrays, with first item being the search value and second the replecement value
	 * @param boolean $caseInsensitive use str_ireplace() instead (optional)
	 * @return string
	 */
	public function render($replacements, $caseInsensitive = FALSE) {
		$content = $this->renderChildren();
		if (is_array($replacements)) {
			foreach ($replacements as $replacement) {
				if (is_array($replacement) && count($replacement) == 2) {
					if ($caseInsensitive) {
						$content = str_ireplace($replacement[0], $replacement[1], $content);
					} else {
						$content = str_replace($replacement[0], $replacement[1], $content);
					}
				}
			}
		}
		return $content;
	}
}